==> vulkan4j-0.1.0-sources.jar: tech/icey/vk4j/datatype/VkPhysicalDeviceCopyMemoryIndirectPropertiesNV.java <==
package tech.icey.vk4j.datatype;

import java.lang.foreign.*;
import static java.lang.foreign.ValueLayout.*;

import tech.icey.panama.IPointer;
import tech.icey.panama.NativeLayout;
import tech.icey.panama.annotation.*;
import tech.icey.panama.buffer.*;
import tech.icey.vk4j.bitmask.*;
import tech.icey.vk4j.datatype.*;
import tech.icey.vk4j.enumtype.*;
import tech.icey.vk4j.handle.*;
import static tech.icey.vk4j.Constants.*;
import static tech.icey.vk4j.enumtype.VkStructureType.*;

/// {@snippet lang=c :
/// typedef struct VkPhysicalDeviceCopyMemoryIndirectPropertiesNV {
///     VkStructureType sType;
///     void* pNext;
///     VkQueueFlags supportedQueues;
/// } VkPhysicalDeviceCopyMemoryIndirectPropertiesNV;}
///
/// @see <a href="https://registry.khronos.org/vulkan/specs/1.3-extensions/man/html/VkPhysicalDeviceCopyMemoryIndirectPropertiesNV.html">VkPhysicalDeviceCopyMemoryIndirectPropertiesNV</a>
public record VkPhysicalDeviceCopyMemoryIndirectPropertiesNV(MemorySegment segment) implements IPointer {
    public VkPhysicalDeviceCopyMemoryIndirectPropertiesNV(MemorySegment segment) {
        this.segment = segment;
        this.sType(VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_COPY_MEMORY_INDIRECT_PROPERTIES_NV);
    }

    public @enumtype(VkStructureType.class) int sType() {
        return segment.get(LAYOUT$sType, OFFSET$sType);
    }

    public void sType(@enumtype(VkStructureType.class) int value) {
        segment.set(LAYOUT$sType, OFFSET$sType, value);
    }

    public @pointer(comment="void*") MemorySegment pNext() {
        return segment.get(LAYOUT$pNext, OFFSET$pNext);
    }

    public void pNext(@pointer(comment="void*") MemorySegment value) {
        segment.set(LAYOUT$pNext, OFFSET$pNext, value);
    }

    public void pNext(@nullable IPointer pointer) {
        pNext(pointer == null ? MemorySegment.NULL : pointer.segment());
    }

    public @enumtype(VkQueueFlags.class) int supportedQueues() {
        return segment.get(LAYOUT$supportedQueues, OFFSET$supportedQueues);
    }

    public void supportedQueues(@enumtype(VkQueueFlags.class) int value) {
        segment.set(LAYOUT$supportedQueues, OFFSET$supportedQueues, value);
    }

    public static VkPhysicalDeviceCopyMemoryIndirectPropertiesNV allocate(Arena arena) {
        return new VkPhysicalDeviceCopyMemoryIndirectPropertiesNV(arena.allocate(LAYOUT));
    }

    public static VkPhysicalDeviceCopyMemoryIndirectPropertiesNV[] allocate(Arena arena, int count) {
        MemorySegment segment = arena.allocate(LAYOUT, count);
        VkPhysicalDeviceCopyMemoryIndirectPropertiesNV[] ret = new VkPhysicalDeviceCopyMemoryIndirectPropertiesNV[count];
        for (int i = 0; i < count; i++) {
            ret[i] = new VkPhysicalDeviceCopyMemoryIndirectPropertiesNV(segment.asSlice(i * SIZE, SIZE));
        }
        return ret;
    }

    public static VkPhysicalDeviceCopyMemoryIndirectPropertiesNV clone(Arena arena, VkPhysicalDeviceCopyMemoryIndirectPropertiesNV src) {
        VkPhysicalDeviceCopyMemoryIndirectPropertiesNV ret = allocate(arena);
        ret.segment.copyFrom(src.segment);
        return ret;
    }

    public static VkPhysicalDeviceCopyMemoryIndirectPropertiesNV[] clone(Arena arena, VkPhysicalDeviceCopyMemoryIndirectPropertiesNV[] src) {
        VkPhysicalDeviceCopyMemoryIndirectPropertiesNV[] ret = allocate(arena, src.length);
        for (int i = 0; i < src.length; i++) {
            ret[i].segment.copyFrom(src[i].segment);
        }
        return ret;
    }

    public static final MemoryLayout LAYOUT = NativeLayout.structLayout(
        ValueLayout.JAVA_INT.withName("sType"),
        ValueLayout.ADDRESS.withName("pNext"),
        ValueLayout.JAVA_INT.withName("supportedQueues")
    );
    public static final long SIZE = LAYOUT.byteSize();

    public static final PathElement PATH$sType = PathElement.groupElement("sType");
    public static final PathElement PATH$pNext = PathElement.groupElement("pNext");
    public static final PathElement PATH$supportedQueues = PathElement.groupElement("supportedQueues");

    public static final OfInt LAYOUT$sType = (OfInt) LAYOUT.select(PATH$sType);
    public static final AddressLayout LAYOUT$pNext = (AddressLayout) LAYOUT.select(PATH$pNext);
    public static final OfInt LAYOUT$supportedQueues = (OfInt) LAYOUT.select(PATH$supportedQueues);

    public static final long OFFSET$sType = LAYOUT.byteOffset(PATH$sType);
    public static final long OFFSET$pNext = LAYOUT.byteOffset(PATH$pNext);
    public static final long OFFSET$supportedQueues = LAYOUT.byteOffset(PATH$supportedQueues);

    public static final long SIZE$sType = LAYOUT$sType.byteSize();
    public static final long SIZE$pNext = LAYOUT$pNext.byteSize();
    public static final long SIZE$supportedQueues = LAYOUT$supportedQueues.byteSize();
}

==> vulkan4j-0.2.2-sources.jar: tech/icey/vk4j/datatype/VkPhysicalDeviceCopyMemoryIndirectPropertiesNV.java <==
package tech.icey.vk4j.datatype;

import java.lang.foreign.*;
import static java.lang.foreign.ValueLayout.*;

import org.jetbrains.annotations.Nullable;
import tech.icey.panama.IPointer;
import tech.icey.panama.NativeLayout;
import tech.icey.panama.annotation.*;
import tech.icey.panama.buffer.*;
import tech.icey.vk4j.bitmask.*;
import tech.icey.vk4j.datatype.*;
import tech.icey.vk4j.enumtype.*;
import tech.icey.vk4j.handle.*;
import static tech.icey.vk4j.Constants.*;
import static tech.icey.vk4j.enumtype.VkStructureType.*;

/// {@snippet lang=c :
/// typedef struct VkPhysicalDeviceCopyMemoryIndirectPropertiesNV {
///     VkStructureType sType;
///     void* pNext;
///     VkQueueFlags supportedQueues;
/// } VkPhysicalDeviceCopyMemoryIndirectPropertiesNV;}
///
/// @see <a href="https://registry.khronos.org/vulkan/specs/1.3-extensions/man/html/VkPhysicalDeviceCopyMemoryIndirectPropertiesNV.html">VkPhysicalDeviceCopyMemoryIndirectPropertiesNV</a>
public record VkPhysicalDeviceCopyMemoryIndirectPropertiesNV(MemorySegment segment) implements IPointer {
    public VkPhysicalDeviceCopyMemoryIndirectPropertiesNV(MemorySegment segment) {
        this.segment = segment;
        this.sType(VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_COPY_MEMORY_INDIRECT_PROPERTIES_NV);
    }

    public @enumtype(VkStructureType.class) int sType() {
        return segment.get(LAYOUT$sType, OFFSET$sType);
    }

    public void sType(@enumtype(VkStructureType.class) int value) {
        segment.set(LAYOUT$sType, OFFSET$sType, value);
    }

    public @pointer(comment="void*") MemorySegment pNext() {
        return segment.get(LAYOUT$pNext, OFFSET$pNext);
    }

    public void pNext(@pointer(comment="void*") MemorySegment value) {
        segment.set(LAYOUT$pNext, OFFSET$pNext, value);
    }

    public void pNext(@Nullable IPointer pointer) {
        pNext(pointer == null ? MemorySegment.NULL : pointer.segment());
    }

    public @enumtype(VkQueueFlags.class) int supportedQueues() {
        return segment.get(LAYOUT$supportedQueues, OFFSET$supportedQueues);
    }

    public void supportedQueues(@enumtype(VkQueueFlags.class) int value) {
        segment.set(LAYOUT$supportedQueues, OFFSET$supportedQueues, value);
    }

    public static VkPhysicalDeviceCopyMemoryIndirectPropertiesNV allocate(Arena arena) {
        return new VkPhysicalDeviceCopyMemoryIndirectPropertiesNV(arena.allocate(LAYOUT));
    }

    public static VkPhysicalDeviceCopyMemoryIndirectPropertiesNV[] allocate(Arena arena, int count) {
        MemorySegment segment = arena.allocate(LAYOUT, count);
        VkPhysicalDeviceCopyMemoryIndirectPropertiesNV[] ret = new VkPhysicalDeviceCopyMemoryIndirectPropertiesNV[count];
        for (int i = 0; i < count; i++) {
            ret[i] = new VkPhysicalDeviceCopyMemoryIndirectPropertiesNV(segment.asSlice(i * SIZE, SIZE));
        }
        return ret;
    }

    public static VkPhysicalDeviceCopyMemoryIndirectPropertiesNV clone(Arena arena, VkPhysicalDeviceCopyMemoryIndirectPropertiesNV src) {
        VkPhysicalDeviceCopyMemoryIndirectPropertiesNV ret = allocate(arena);
        ret.segment.copyFrom(src.segment);
        return ret;
    }

    public static VkPhysicalDeviceCopyMemoryIndirectPropertiesNV[] clone(Arena arena, VkPhysicalDeviceCopyMemoryIndirectPropertiesNV[] src) {
        VkPhysicalDeviceCopyMemoryIndirectPropertiesNV[] ret = allocate(arena, src.length);
        for (int i = 0; i < src.length; i++) {
            ret[i].segment.copyFrom(src[i].segment);
        }
        return ret;
    }

    public static final MemoryLayout LAYOUT = NativeLayout.structLayout(
        ValueLayout.JAVA_INT.withName("sType"),
        ValueLayout.ADDRESS.withName("pNext"),
        ValueLayout.JAVA_INT.withName("supportedQueues")
    );
    public static final long SIZE = LAYOUT.byteSize();

    public static final PathElement PATH$sType = PathElement.groupElement("sType");
    public static final PathElement PATH$pNext = PathElement.groupElement("pNext");
    public static final PathElement PATH$supportedQueues = PathElement.groupElement("supportedQueues");

    public static final OfInt LAYOUT$sType = (OfInt) LAYOUT.select(PATH$sType);
    public static final AddressLayout LAYOUT$pNext = (AddressLayout) LAYOUT.select(PATH$pNext);
    public static final OfInt LAYOUT$supportedQueues = (OfInt) LAYOUT.select(PATH$supportedQueues);

    public static final long OFFSET$sType = LAYOUT.byteOffset(PATH$sType);
    public static final long OFFSET$pNext = LAYOUT.byteOffset(PATH$pNext);
    public static final long OFFSET$supportedQueues = LAYOUT.byteOffset(PATH$supportedQueues);

    public static final long SIZE$sType = LAYOUT$sType.byteSize();
    public static final long SIZE$pNext = LAYOUT$pNext.byteSize();
    public static final long SIZE$supportedQueues = LAYOUT$supportedQueues.byteSize();
}
